@@ -1,4 +1,4 @@
-package Sim::OPT::Interlinear;
+#package Sim::OPT::Interlinear;
 # NOTE: TO USE THE PROGRAM AS A SCRIPT, THE LINE ABOVE SHOULD BE DELETED.
 
 # INTERLINEAR
@@ -22,13 +22,13 @@ use feature 'say';
 no strict;
 no warnings;
 
-use Sim::OPT;
-use Sim::OPT::Morph;
-use Sim::OPT::Sim;
-use Sim::OPT::Report;
-use Sim::OPT::Descend;
-use Sim::OPT::Takechance;
-use Sim::OPT::Parcoord3d;
+#use Sim::OPT;
+#use Sim::OPT::Morph;
+#use Sim::OPT::Sim;
+#use Sim::OPT::Report;
+#use Sim::OPT::Descend;
+#use Sim::OPT::Takechance;
+#use Sim::OPT::Parcoord3d;
 # NOTE: TO USE THE PROGRAM AS A SCRIPT, THE ABOVE "use Sim::OPT..." lines should be deleted.
 
 our @ISA = qw( Exporter );
@@ -703,7 +703,7 @@ sub wei
   my %factlevels = %{ $factlevels_ref };  #say $tee "AND \%factlevels: " . dump( %factlevels );
   # my ( %magic, %wand, %spell, %bank );
   my %bank = %{ $bank_ref };
-  my %nears = %{ $nears_ref }; say $tee " \%nearsIN1: " . dump( \%nears );
+  my %nears = %{ $nears_ref }; #say $tee " \%nearsIN1: " . dump( \%nears );
 
   my %weldnears;
 
@@ -714,7 +714,7 @@ sub wei
   my @recedes = @{ $recedes_ref }; #say $tee "NOW \@recedes: " . dump( @recedes );
 ###--###
 
-  say "nfilter: $nfilter.";
+  #say "nfilter: $nfilter.";
   $nfilter = ( $nfilter - 1 );
 
   my @arr__;
@@ -756,12 +756,12 @@ sub wei
 
   sub fillbank
   { #say $tee "NOW IN FILLBANK.";
-    say $tee " \%nearsIN2: " . dump( \%nears );
+    #say $tee " \%nearsIN2: " . dump( \%nears );
     my ( $arr_r, $minimumcertain, $minreq_forgrad, $maxdist, $condweight, $factlevels_r, $nfilter, $arra_r, $first0, $last0, $nears_ref ) = @_;
     my @arr = @{ $arr_r };
     my @arra = @{ $arra_r };
     my %factlevels = %{ $factlevels_r };
-    my %nears = %{ $nears_ref }; say $tee " \%nearsIN3: " . dump( \%nears );
+    my %nears = %{ $nears_ref }; #say $tee " \%nearsIN3: " . dump( \%nears );
     #my $nstop;
     #if ( $nfilter ne "" )
     #{
@@ -1043,7 +1043,7 @@ sub wei
   {
     say $tee "Entering gradients' \%bank.";
     my ( $bank_ref, $nears_ref ) = fillbank( \@arr__, $minimumcertain, $minreq_forgrad, $maxdist, $condweight, \%factlevels, $nfilter, \@arra, $first0, $last0, \%nears );
-    %bank = %{ $bank_ref }; say $tee "\%bank: " . dump( %bank );
+    %bank = %{ $bank_ref }; #say $tee "\%bank: " . dump( %bank );
     %nears = %{ $nears_ref };
     %bank = %{ clean( \%bank, $nfilter, "principal", \@recedes ) }; say $tee "BANK DONE."; #say $tee "CLEANED \%bank: " . dump( %bank ) ;
   }
@@ -1060,7 +1060,7 @@ sub wei
     {
       unless ( $trio eq "" )
       {
-        my @splits = split( "-", $trio ); say $tee "\@splits " . dump( @splits );
+        my @splits = split( "-", $trio ); #say $tee "\@splits " . dump( @splits );
         my $num = $splits[0];
         if ( $num ~~ @parsws )
         {
@@ -1140,13 +1140,13 @@ sub wei
       #say $tee " \%factlevels: " . dump( \%factlevels ) ;
       #say $tee " \@weldarra: " . dump( \@weldarra ) ;
       my ( $weldbank_ref, $weldnears_ref ) = fillbank( \@weldarr__, $minimumcertain, $minreq_forgrad, $maxdist, $condweight, \%factlevels, $nfilter, \@weldarra, $first0, $last0, \%nears );##%weldnears!!!!
-      %weldbank = %{ $weldbank_ref }; say $tee " \%weldbank: " . dump( \%weldbank ) ;
+      %weldbank = %{ $weldbank_ref }; #say $tee " \%weldbank: " . dump( \%weldbank ) ;
       %weldnears = %{ $weldnears_ref };
 
       %weldbank = %{ clean( \%weldbank, $nfilter, "weld" ) }; #say $tee "CLEANED \%weldbank: " . dump( \%weldbank ) ;
 
       %bank = %{ mixbank( \%bank, \%weldbank, \@parsws ) };
-      say $tee "COMPLETED \%bank:" . dump( \%bank ) . ": COMPLETED \%bank.";
+      #say $tee "COMPLETED \%bank:" . dump( \%bank ) . ": COMPLETED \%bank.";
       say $tee "KEYS \%bank: " . ( keys %bank );
 
       $co++;
